Struct wasmtime_cache::ModuleCacheEntry [−][src]
pub struct ModuleCacheEntry<'config>(_);Expand description
Module level cache entry.
Implementations
Create the cache entry.
Gets cached data if state matches, otherwise calls compute.
Data is automatically serialized/deserialized with bincode.
Gets cached data if state matches, otherwise calls compute.
If the cache is disabled or no cached data is found then compute is
called to calculate the data. If the data was found in cache it is
passed to deserialize, which if successful will be the returned value.
When computed the serialize function is used to generate the bytes
from the returned value.