Struct wasmtime_cache::CacheConfig [−][src]
pub struct CacheConfig { /* fields omitted */ }Expand description
Global configuration for how the cache is managed
Implementations
impl CacheConfig[src]
impl CacheConfig[src]pub fn worker_event_queue_size(&self) -> u64[src]
pub fn worker_event_queue_size(&self) -> u64[src]Returns $setting.
Panics if the cache is disabled.
pub fn baseline_compression_level(&self) -> i32[src]
pub fn baseline_compression_level(&self) -> i32[src]Returns $setting.
Panics if the cache is disabled.
pub fn optimized_compression_level(&self) -> i32[src]
pub fn optimized_compression_level(&self) -> i32[src]Returns $setting.
Panics if the cache is disabled.
pub fn optimized_compression_usage_counter_threshold(&self) -> u64[src]
pub fn optimized_compression_usage_counter_threshold(&self) -> u64[src]Returns $setting.
Panics if the cache is disabled.
pub fn cleanup_interval(&self) -> Duration[src]
pub fn cleanup_interval(&self) -> Duration[src]Returns $setting.
Panics if the cache is disabled.
pub fn optimizing_compression_task_timeout(&self) -> Duration[src]
pub fn optimizing_compression_task_timeout(&self) -> Duration[src]Returns $setting.
Panics if the cache is disabled.
pub fn allowed_clock_drift_for_files_from_future(&self) -> Duration[src]
pub fn allowed_clock_drift_for_files_from_future(&self) -> Duration[src]Returns $setting.
Panics if the cache is disabled.
pub fn file_count_soft_limit(&self) -> u64[src]
pub fn file_count_soft_limit(&self) -> u64[src]Returns $setting.
Panics if the cache is disabled.
pub fn files_total_size_soft_limit(&self) -> u64[src]
pub fn files_total_size_soft_limit(&self) -> u64[src]Returns $setting.
Panics if the cache is disabled.
pub fn file_count_limit_percent_if_deleting(&self) -> u8[src]
pub fn file_count_limit_percent_if_deleting(&self) -> u8[src]Returns $setting.
Panics if the cache is disabled.
pub fn files_total_size_limit_percent_if_deleting(&self) -> u8[src]
pub fn files_total_size_limit_percent_if_deleting(&self) -> u8[src]Returns $setting.
Panics if the cache is disabled.
pub fn directory(&self) -> &PathBuf[src]
pub fn directory(&self) -> &PathBuf[src]Returns path to the cache directory.
Panics if the cache is disabled.
pub fn new_cache_disabled() -> Self[src]
pub fn new_cache_disabled() -> Self[src]Creates a new set of configuration which represents a disabled cache
pub fn from_file(config_file: Option<&Path>) -> Result<Self>[src]
pub fn from_file(config_file: Option<&Path>) -> Result<Self>[src]Parses cache configuration from the file specified
pub fn cache_hits(&self) -> usize[src]
pub fn cache_hits(&self) -> usize[src]Returns the number of cache hits seen so far
pub fn cache_misses(&self) -> usize[src]
pub fn cache_misses(&self) -> usize[src]Returns the number of cache misses seen so far